pub(crate) fn uint_to_be_pad(
input: BoxedUint,
padded_len: usize,
) -> Result<Vec<u8>>Expand description
Converts input to the new vector of the given length, using BE and with 0s left padded. In some cases BoxedUint might already have leading zeroes, this function removes them before padding again.