uint_to_zeroizing_be_pad

Function uint_to_zeroizing_be_pad 

pub(crate) fn uint_to_zeroizing_be_pad(
    input: BoxedUint,
    padded_len: usize,
) -> Result<Vec<u8>>
Converts input to the new vector of the given length, using BE and with 0s left padded. In some cases BoxedUint might already have leading zeroes, this function removes them before padding again.